![logo](logo.png)

v. 0.0.11

# aerosol-functions
A collection of methods to analyze and visualize atmospheric aerosol data.

## Installation
`pip install aerosol-functions`

## [Documentation](https://jlpl.github.io/aerosol-functions/)
